@@ -216,8 +216,6 @@ class PlasmaEffect(BaseEffect):
         self.info  = False
         self.random = False
         self.scale = random.choice(_GREY_SCALES)
-        print(self.scale)
-        print(len(self.scale))
         self.ayo   = 0
         self.vals  = [random.randint(1, 50), random.randint(
             1, 50), random.randint(1, 50), random.randint(1, 50)]
@@ -293,8 +291,6 @@ class PlasmaEffect(BaseEffect):
         Function to render the next frame of the Plasma Effect
         """
         self.ayo += 1
-        if frame_number == 0:
-            print(self.colors)
         for y in range(self.buffer.height()):
             for x in range(self.buffer.width()):
                 value = abs(self.func(x + self.ayo / 3, y, 1/4, 1/3, self.vals[0]) + self.func(x, y, 1/8, 1/5, self.vals[1])
